``cocotb`` - ``sax``
------------------------

This integration aims to provide an co-design mechanism for solving
photonic circuit networking. One common application might be to see how
a set of configured phase-shifter switches, might affect the total
output of a system, and how this corresponds to the electronic function
that is applied in order to drive it.
